Enum rmp::decode::FixedValueReadError [] [src]

pub enum FixedValueReadError {
    UnexpectedEOF,
    Io(Error),
    TypeMismatch(Marker),
}

Represents an error that can occur when attempting to read a MessagePack'ed single-byte value from the reader.

Variants

Unexpected end of file reached while reading the value.

I/O error occurred while reading the value.

The type decoded isn't match with the expected one.