Enum rmp::decode::MarkerReadError [] [src]

pub enum MarkerReadError {
    UnexpectedEOF,
    Io(Error),
}

Represents an error that can occur when attempting to read a MessagePack marker from the reader.

This is a thin wrapper over the standard io::Error type. Namely, it adds one additional error case: an unexpected EOF.

Variants

Unexpected end of file reached while reading the marker.

I/O error occurred while reading the marker.