Enum rmp::decode::FixedValueReadError
[−]
[src]
pub enum FixedValueReadError {
UnexpectedEOF,
Io(Error),
TypeMismatch(Marker),
}Represents an error that can occur when attempting to read a MessagePack'ed single-byte value from the reader.
Variants
UnexpectedEOFUnexpected end of file reached while reading the value.
Io(Error)I/O error occurred while reading the value.
TypeMismatch(Marker)The type decoded isn't match with the expected one.