Enum rmp::decode::ReadError
[−]
[src]
pub enum ReadError {
UnexpectedEOF,
Io(Error),
}Represents an error that can occur when attempting to read bytes from the reader.
This is a thin wrapper over the standard io::Error type. Namely, it adds one additional error
case: an unexpected EOF.
Variants
UnexpectedEOFUnexpected end of file reached while reading bytes.
Io(Error)I/O error occurred while reading bytes.